@@ -412,9 +412,9 @@ bool CControlSocket::ParsePwdReply(wxString reply, bool unquoted /*=false*/, con
 	if (reply == _T("") || !m_CurrentPath.SetPath(reply))
 	{
 		if (reply != _T(""))
-			LogMessage(__TFILE__, __LINE__, this, Debug_Warning, _T("Failed to parse returned path."));
+			LogMessage(::Error, _("Failed to parse returned path."));
 		else
-			LogMessage(__TFILE__, __LINE__, this, Debug_Warning, _T("Server returned empty path."));
+			LogMessage(::Error, _("Server returned empty path."));
 
 		if (!defaultPath.IsEmpty())
 		{
@@ -500,7 +500,7 @@ int CControlSocket::CheckOverwriteFile()
 	{
 		if (!pData->fileTime.IsValid())
 		{
-			if (entry.hasTimestamp != CDirentry::timestamp_none)
+			if (entry.has_date())
 			{
 				pNotification->remoteTime = entry.time;
 				pData->fileTime = entry.time;
@@ -1358,7 +1358,7 @@ bool CControlSocket::SetFileExistsAction(CFileExistsNotification *pFileExistsNot
 			{
 				wxLongLong size = entry.size;
 				pData->remoteFileSize = size.GetLo() + ((wxFileOffset)size.GetHi() << 32);
-				if (entry.hasTimestamp != CDirentry::timestamp_none)
+				if (entry.has_date())
 					pData->fileTime = entry.time;
 
 				if (CheckOverwriteFile() != FZ_REPLY_OK)
