@@ -1,11 +1,12 @@
 #include <filezilla.h>
 #include "serverpath.h"
+#include "string_coalescer.h"
 
 #define FTP_MVS_DOUBLE_QUOTE (wxChar)0xDC
 
 struct CServerTypeTraits
 {
-	wxChar separator;
+	const wxChar* separators;
 	bool has_root; // Root = simply separator nothing else
 	wxChar left_enclosure; // Example: VMS paths: [FOO.BAR]
 	wxChar right_enclosure;
@@ -17,16 +18,16 @@ struct CServerTypeTraits
 };
 
 static const CServerTypeTraits traits[SERVERTYPE_MAX] = {
-	{ '/',  true,  0,    0,    false, 0, 0,   true,  false }, // Failsafe
-	{ '/',  true,  0,    0,    false, 0, 0,   true,  false },
-	{ '.',  false, '[',  ']',  false, 0, '^', false, false },
-	{ '\\', false, 0,    0,    false, 0, 0,   true,  false },
-	{ '.',  false, '\'', '\'', true,  1, 0,   false, false },
-	{ '/',  true,  0,    0,    false, 0, 0,   true,  false },
-	{ '/',  true,  0,    0,    false, 0, 0,   true,  false }, // Same as Unix
-	{ '.',  false, 0,    0,    false, 0, 0,   false, false },
-	{ '\\', true,  0,    0,    false, 0, 0,   true,  false },
-	{ '/',  true,  0,    0,    false, 0, 0,   true,  true  } // Cygwin is like Unix but has optional prefix of form "//server"
+	{ _T("/"),  true,  0,    0,    false, 0, 0,   true,  false }, // Failsafe
+	{ _T("/"),  true,  0,    0,    false, 0, 0,   true,  false },
+	{ _T("."),  false, '[',  ']',  false, 0, '^', false, false },
+	{ _T("\\/"), false, 0,    0,    false, 0, 0,   true,  false },
+	{ _T("."),  false, '\'', '\'', true,  1, 0,   false, false },
+	{ _T("/"),  true,  0,    0,    false, 0, 0,   true,  false },
+	{ _T("/"),  true,  0,    0,    false, 0, 0,   true,  false }, // Same as Unix
+	{ _T("."),  false, 0,    0,    false, 0, 0,   false, false },
+	{ _T("\\"), true,  0,    0,    false, 0, 0,   true,  false },
+	{ _T("/"),  true,  0,    0,    false, 0, 0,   true,  true  } // Cygwin is like Unix but has optional prefix of form "//server"
 };
 
 CServerPathData::CServerPathData()
@@ -161,23 +162,23 @@ wxString CServerPath::GetPath() const
 	if (traits[m_type].left_enclosure != 0)
 		path += traits[m_type].left_enclosure;
 	if (m_data->m_segments.empty() && (!traits[m_type].has_root || m_data->m_prefix.empty() || traits[m_type].separator_after_prefix))
-		path += traits[m_type].separator;
+		path += traits[m_type].separators[0];
 
-	for (tConstSegmentIter iter = m_data->m_segments.begin(); iter != m_data->m_segments.end(); iter++)
+	for (tConstSegmentIter iter = m_data->m_segments.begin(); iter != m_data->m_segments.end(); ++iter)
 	{
 		const wxString& segment = *iter;
 		if (iter != m_data->m_segments.begin())
-			path += traits[m_type].separator;
+			path += traits[m_type].separators[0];
 		else if (traits[m_type].has_root)
 		{
 			if (m_data->m_prefix.empty() || traits[m_type].separator_after_prefix)
-				path += traits[m_type].separator;
+				path += traits[m_type].separators[0];
 		}
 
 		if (traits[m_type].separatorEscape)
 		{
 			wxString tmp = segment;
-			tmp.Replace((wxString)traits[m_type].separator, (wxString)traits[m_type].separatorEscape + traits[m_type].separator);
+			EscapeSeparators(m_type, tmp);
 			path += tmp;
 		}
 		else
@@ -193,7 +194,7 @@ wxString CServerPath::GetPath() const
 	// DOS is strange.
 	// C: is current working dir on drive C, C:\ the drive root.
 	if (m_type == DOS && m_data->m_segments.size() == 1)
-		path += traits[m_type].separator;
+		path += traits[m_type].separators[0];
 
 	return path;
 }
@@ -236,26 +237,78 @@ wxString CServerPath::GetLastSegment() const
 		return _T("");
 }
 
+// libc sprintf can be so slow at times...
+wxChar* fast_sprint_number(wxChar* s, size_t n)
+{
+	wxChar tmp[20]; // Long enough for 2^64-1
+
+	wxChar* c = tmp;
+	do
+	{
+		*(c++) = n % 10 + '0';
+		n /= 10;
+	} while( n > 0 );
+
+	do
+	{
+		*(s++) = *(--c);
+	} while (c != tmp);
+
+	return s;
+}
+
+#ifdef wxUSE_UNICODE
+#define tstrcpy wcscpy
+#else
+#define tstrcpy strcpy
+#endif
+
 wxString CServerPath::GetSafePath() const
 {
 	if (m_bEmpty)
 		return _T("");
 
+	#define INTLENGTH 20 // 2^64 - 1
+
+	int len = 5 // Type and 2x' ' and terminating 0
+		+ INTLENGTH; // Max length of prefix
+
+	len += m_data->m_prefix.size();
+	for (tConstSegmentIter iter = m_data->m_segments.begin(); iter != m_data->m_segments.end(); ++iter)
+		len += iter->Length() + 2 + INTLENGTH;
+
 	wxString safepath;
-	safepath.Printf(_T("%d %d "), m_type, (int)m_data->m_prefix.Length());
-	if (m_data->m_prefix != _T(""))
-		safepath += m_data->m_prefix + _T(" ");
+	wxChar* start = safepath.GetWriteBuf(len);
+	wxChar* t = start;
 
-	for (tConstSegmentIter iter = m_data->m_segments.begin(); iter != m_data->m_segments.end(); iter++)
-		safepath += wxString::Format(_T("%d %s "), (int)iter->Length(), iter->c_str());
+	t = fast_sprint_number(t, m_type);
+	*(t++) = ' ';
+	t = fast_sprint_number(t, m_data->m_prefix.size());
 
-	if (!m_data->m_segments.empty())
-		safepath.RemoveLast();
+	if (!m_data->m_prefix.empty())
+	{
+		*(t++) = ' ';
+		tstrcpy(t, m_data->m_prefix);
+		t += m_data->m_prefix.size();
+	}
+
+	for (tConstSegmentIter iter = m_data->m_segments.begin(); iter != m_data->m_segments.end(); ++iter)
+	{
+		*(t++) = ' ';
+		t = fast_sprint_number(t, iter->size());
+		*(t++) = ' ';
+		tstrcpy(t, *iter);
+		t += iter->size();
+	}
+	*t = 0;
+
+	safepath.UngetWriteBuf( t - start );
+	safepath.Shrink();
 
 	return safepath;
 }
 
-bool CServerPath::SetSafePath(const wxString& path)
+bool CServerPath::SetSafePath(const wxString& path, bool coalesce)
 {
 	CServerPathData& data = m_data.Get();
 	m_bEmpty = true;
@@ -268,7 +321,7 @@ bool CServerPath::SetSafePath(const wxString& path)
 	// from file
 	const int len = (int)path.Len();
 	wxChar* begin = new wxChar[len + 1];
-	CSharedPointerArray<wxChar> tmp(begin);
+	CScopedArray<wxChar> tmp(begin);
 	memcpy(begin, (const wxChar*)path, (len + 1) * sizeof(wxChar));
 	wxChar* p = begin;
 
@@ -282,11 +335,11 @@ bool CServerPath::SetSafePath(const wxString& path)
 
 		if (type >= SERVERTYPE_MAX)
 			return false;
-		p++;
+		++p;
 	} while (*p != ' ');
 
 	m_type = (ServerType)type;
-	p++;
+	++p;
 
 	int prefix_len = 0;
 	do
@@ -298,7 +351,7 @@ bool CServerPath::SetSafePath(const wxString& path)
 
 		if (prefix_len > 32767) // Should be sane enough
 			return false;
-		p++;
+		++p;
 	}
 	while (*p && *p != ' ');
 
@@ -314,7 +367,7 @@ bool CServerPath::SetSafePath(const wxString& path)
 		}
 	}
 
-	p++;
+	++p;
 
 	if (len - (p - begin) < prefix_len)
 		return false;
@@ -322,6 +375,8 @@ bool CServerPath::SetSafePath(const wxString& path)
 	{
 		*(p + prefix_len) = 0;
 		data.m_prefix = p;
+		if (coalesce)
+			::Coalesce(data.m_prefix);
 
 		p += prefix_len + 1;
 	}
@@ -338,18 +393,21 @@ bool CServerPath::SetSafePath(const wxString& path)
 
 			if (segment_len > 32767) // Should be sane enough
 				return false;
-			p++;
+			++p;
 		}
 		while (*p != ' ');
 
 		if (!segment_len)
 			return false;
-		p++;
+		++p;
 
 		if (len - (p - begin) < segment_len)
 			return false;
 		*(p + segment_len) = 0;
-		data.m_segments.push_back(p);
+		wxString s(p);
+		if (coalesce)
+			::Coalesce(s);
+		data.m_segments.push_back(s);
 
 		p += segment_len + 1;
 	}
@@ -412,8 +470,8 @@ bool CServerPath::IsSubdirOf(const CServerPath &path, bool cmpNoCase) const
 		else if (*iter1 != *iter2)
 			return false;
 
-		iter1++;
-		iter2++;
+		++iter1;
+		++iter2;
 	}
 
 	return false;
@@ -498,7 +556,7 @@ bool CServerPath::ChangePath(wxString &subdir, bool isFile)
 	case DOS:
 		{
 			bool is_relative = false;
-			int sep = dir.Find(traits[m_type].separator);
+			int sep = dir.find_first_of(traits[m_type].separators);
 			if (sep == -1)
 				sep = dir.Len();
 			int colon = dir.Find(':');
@@ -507,7 +565,7 @@ bool CServerPath::ChangePath(wxString &subdir, bool isFile)
 
 			if (is_relative)
 				data.m_segments.clear();
-			else if (dir[0] == traits[m_type].separator)
+			else if (wxString(traits[m_type].separators).Contains(dir[0]))
 			{
 				if (data.m_segments.empty())
 					return false;
@@ -643,7 +701,7 @@ bool CServerPath::ChangePath(wxString &subdir, bool isFile)
 		break;
 	case CYGWIN:
 		{
-			if (dir[0] == traits[m_type].separator)
+			if (wxString(traits[m_type].separators).Contains(dir[0]))
 			{
 				data.m_segments.clear();
 				data.m_prefix.clear();
@@ -652,7 +710,7 @@ bool CServerPath::ChangePath(wxString &subdir, bool isFile)
 				return false;
 			if (dir.Left(2) == _T("//"))
 			{
-				data.m_prefix = traits[m_type].separator;
+				data.m_prefix = traits[m_type].separators[0];
 				dir = dir.Mid(1);
 			}
 
@@ -665,7 +723,7 @@ bool CServerPath::ChangePath(wxString &subdir, bool isFile)
 		break;
 	default:
 		{
-			if (dir[0] == traits[m_type].separator)
+			if (wxString(traits[m_type].separators).Contains(dir[0]))
 				data.m_segments.clear();
 			else if (m_bEmpty)
 				return false;
@@ -737,8 +795,8 @@ bool CServerPath::operator<(const CServerPath &op) const
 	else if (m_type < op.m_type)
 		return true;
 
-	std::list<wxString>::const_iterator iter1, iter2;
-	for (iter1 = m_data->m_segments.begin(), iter2 = op.m_data->m_segments.begin(); iter1 != m_data->m_segments.end(); iter1++, iter2++)
+	tConstSegmentIter iter1, iter2;
+	for (iter1 = m_data->m_segments.begin(), iter2 = op.m_data->m_segments.begin(); iter1 != m_data->m_segments.end(); ++iter1, ++iter2)
 	{
 		if (iter2 == op.m_data->m_segments.end())
 			return false;
@@ -774,15 +832,15 @@ wxString CServerPath::FormatFilename(const wxString &filename, bool omitPath /*=
 	switch (m_type)
 	{
 		case VXWORKS:
-			if (result.Last() != traits[m_type].separator && !m_data->m_segments.empty())
-				result += traits[m_type].separator;
+			if (!wxString(traits[m_type].separators).Contains(result.Last()) && !m_data->m_segments.empty())
+				result += traits[m_type].separators[0];
 			break;
 		case VMS:
 		case MVS:
 			break;
 		default:
-			if (result.Last() != traits[m_type].separator)
-				result += traits[m_type].separator;
+			if (!wxString(traits[m_type].separators).Contains(result.Last()))
+				result += traits[m_type].separators[0];
 			break;
 	}
 
@@ -869,21 +927,21 @@ CServerPath CServerPath::GetCommonParent(const CServerPath& path) const
 
 	CServerPathData& parentData = parent.m_data.Get();
 	
-	std::list<wxString>::const_iterator last = m_data->m_segments.end();
-	std::list<wxString>::const_iterator last2 = path.m_data->m_segments.end();
+	tConstSegmentIter last = m_data->m_segments.end();
+	tConstSegmentIter last2 = path.m_data->m_segments.end();
 	if (traits[m_type].prefixmode == 1)
 	{
 		if (m_data->m_prefix.empty())
-			last--;
+			--last;
 		if (path.m_data->m_prefix.empty())
-			last2--;
+			--last2;
 		parentData.m_prefix = GetParent().m_data->m_prefix;
 	}
 	else
 		parentData.m_prefix = m_data->m_prefix;
 
-	std::list<wxString>::const_iterator iter = m_data->m_segments.begin();
-	std::list<wxString>::const_iterator iter2 = path.m_data->m_segments.begin();
+	tConstSegmentIter iter = m_data->m_segments.begin();
+	tConstSegmentIter iter2 = path.m_data->m_segments.begin();
 	while (iter != last && iter2 != last2)
 	{
 		if (*iter != *iter2)
@@ -896,8 +954,8 @@ CServerPath CServerPath::GetCommonParent(const CServerPath& path) const
 
 		parentData.m_segments.push_back(*iter);
 
-		iter++;
-		iter2++;
+		++iter;
+		++iter2;
 	}
 
 	return parent;
@@ -909,7 +967,7 @@ wxString CServerPath::FormatSubdir(const wxString &subdir) const
 		return subdir;
 
 	wxString res = subdir;
-	res.Replace((wxString)traits[m_type].separator, (wxString)traits[m_type].separatorEscape + traits[m_type].separator);
+	EscapeSeparators(m_type, res);
 
 	return res;
 }
@@ -920,7 +978,7 @@ bool CServerPath::Segmentize(wxString str, tSegmentList& segments)
 	while (!str.empty())
 	{
 		wxString segment;
-		int pos = str.Find(traits[m_type].separator);
+		int pos = str.find_first_of(traits[m_type].separators);
 		if (pos == -1)
 		{
 			segment = str,
@@ -958,7 +1016,7 @@ bool CServerPath::Segmentize(wxString str, tSegmentList& segments)
 		{
 			append_next = true;
 			segment.RemoveLast();
-			segment += traits[m_type].separator;
+			segment += traits[m_type].separators[0];
 		}
 
 		if (append)
@@ -976,7 +1034,7 @@ bool CServerPath::Segmentize(wxString str, tSegmentList& segments)
 
 bool CServerPath::ExtractFile(wxString& dir, wxString& file)
 {
-	int pos = dir.Find(traits[m_type].separator, true);
+	int pos = dir.find_last_of(traits[m_type].separators);
 	if (pos == (int)dir.Length() - 1)
 		return false;
 
@@ -992,3 +1050,20 @@ bool CServerPath::ExtractFile(wxString& dir, wxString& file)
 
 	return true;
 }
+
+void CServerPath::EscapeSeparators(ServerType type, wxString& subdir)
+{
+	if (traits[type].separatorEscape)
+	{
+		for (const wxChar* p = traits[type].separators; *p; ++p)
+			subdir.Replace((wxString)*p, (wxString)traits[type].separatorEscape + traits[type].separators[0]);
+	}
+}
+
+void CServerPath::Coalesce()
+{
+	CServerPathData& data = m_data.Get();
+	::Coalesce(data.m_prefix);
+	for (tSegmentIter iter = data.m_segments.begin(); iter != data.m_segments.end(); ++iter)
+		::Coalesce(*iter);
+}
