@@ -206,6 +206,7 @@ protected:
 };
 
 CMainFrame::CMainFrame()
+	: m_comparisonToggleAcceleratorId(wxNewId())
 {
 	wxRect screen_size = CWindowStateManager::GetScreenDimensions();
 
@@ -412,12 +413,13 @@ CMainFrame::CMainFrame()
 		SetDefaultSplitterPositions();
 
 	wxAcceleratorEntry entries[11];
-	entries[0].Set(wxACCEL_CMD | wxACCEL_SHIFT, 'I', XRCID("ID_MENU_VIEW_FILTERS"));
+	//entries[0].Set(wxACCEL_CMD | wxACCEL_SHIFT, 'I', XRCID("ID_MENU_VIEW_FILTERS"));
 	for (int i = 0; i < 10; i++)
 	{
 		tab_hotkey_ids[i] = wxNewId();
-		entries[i + 1].Set(wxACCEL_CMD, (int)'0' + i, tab_hotkey_ids[i]);
+		entries[i].Set(wxACCEL_CMD, (int)'0' + i, tab_hotkey_ids[i]);
 	}
+	entries[10].Set(wxACCEL_CMD | wxACCEL_SHIFT, 'O', m_comparisonToggleAcceleratorId);
 
 	wxAcceleratorTable accel(sizeof(entries) / sizeof(wxAcceleratorEntry), entries);
 	SetAcceleratorTable(accel);
@@ -878,6 +880,19 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		CSpeedLimitsDialog dlg;
 		dlg.Run(this);
 	}
+	else if (event.GetId() == m_comparisonToggleAcceleratorId)
+	{
+		CState* pState = CContextManager::Get()->GetCurrentContext();
+		if (!pState)
+			return;
+
+		int old_mode = COptions::Get()->GetOptionVal(OPTION_COMPARISONMODE);
+		COptions::Get()->SetOption(OPTION_COMPARISONMODE, old_mode ? 0 : 1);
+
+		CComparisonManager* pComparisonManager = pState->GetComparisonManager();
+		if (pComparisonManager && pComparisonManager->IsComparing())
+			pComparisonManager->CompareListings();
+	}
 	else
 	{
 		for (int i = 0; i < 10; i++)
@@ -2750,6 +2765,8 @@ void CMainFrame::OnToggleToolBar(wxCommandEvent& event)
 		m_pToolBar->Show( event.IsChecked() );
 #else
 	CreateToolBar();
+	if (m_pToolBar)
+		m_pToolBar->UpdateToolbarState();
 	HandleResize();
 #endif
 }
