@@ -38,8 +38,6 @@ END_EVENT_TABLE()
 #ifdef __WXMSW__
 // wxWidgets does not handle LVN_ODSTATECHANGED, work around it
 
-template<class CFileData> std::map<HWND, char*> CFileListCtrl<CFileData>::m_hwnd_map;
-
 #pragma pack(push, 1)
 typedef struct fz_tagNMLVODSTATECHANGE
 {
@@ -65,69 +63,66 @@ typedef struct fz_tagNMLVODSTATECHANGE
 #define GET_APPCOMMAND_LPARAM(x) (HIWORD(x)&~0xF000)
 #endif
 
-template<class CFileData> LRESULT CALLBACK CFileListCtrl<CFileData>::WindowProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
+template<class CFileData> WXLRESULT CFileListCtrl<CFileData>::MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lParam)
 {
-	std::map<HWND, char*>::iterator iter = m_hwnd_map.find(hWnd);
-	if (iter == m_hwnd_map.end())
-	{
-		// This shouldn't happen
-		return 0;
-	}
-	CFileListCtrl<CFileData>* pFileListCtrl = (CFileListCtrl<CFileData>*)iter->second;
-
-	if (uMsg == WM_APPCOMMAND)
+	if (nMsg == WM_APPCOMMAND)
 	{
 		DWORD cmd = GET_APPCOMMAND_LPARAM(lParam);
 		if (cmd == APPCOMMAND_BROWSER_FORWARD)
 		{
-			pFileListCtrl->OnNavigationEvent(true);
+			OnNavigationEvent(true);
 			return true;
 		}
 		else if (cmd == APPCOMMAND_BROWSER_BACKWARD)
 		{
-			pFileListCtrl->OnNavigationEvent(false);
+			OnNavigationEvent(false);
 			return true;
 		}
 
-		return CallWindowProc(pFileListCtrl->m_prevWndproc, hWnd, uMsg, wParam, lParam);
+		return wxListCtrlEx::MSWWindowProc(nMsg, wParam, lParam);
 	}
-	else if (uMsg != WM_NOTIFY)
-		return CallWindowProc(pFileListCtrl->m_prevWndproc, hWnd, uMsg, wParam, lParam);
+	
+	return wxListCtrlEx::MSWWindowProc(nMsg, wParam, lParam);
+}
 
-	if (!pFileListCtrl->m_pFilelistStatusBar)
-		return CallWindowProc(pFileListCtrl->m_prevWndproc, hWnd, uMsg, wParam, lParam);
+template<class CFileData> bool CFileListCtrl<CFileData>::MSWOnNotify(int idCtrl, WXLPARAM lParam, WXLPARAM *result)
+{
+	if (!m_pFilelistStatusBar)
+		return wxListCtrlEx::MSWOnNotify(idCtrl, lParam, result);
+
+	*result = 0;
 
 	NMHDR* pNmhdr = (NMHDR*)lParam;
 	if (pNmhdr->code == LVN_ODSTATECHANGED)
 	{
 		// A range of items got (de)selected
 
-		if (pFileListCtrl->m_insideSetSelection)
-			return 0;
+		if (m_insideSetSelection)
+			return true;
 
-		if (!pFileListCtrl->m_pFilelistStatusBar)
-				return 0;
+		if (!m_pFilelistStatusBar)
+			return true;
 		
 		if (wxGetKeyState(WXK_CONTROL) && wxGetKeyState(WXK_SHIFT))
 		{
 			// The behavior of Ctrl+Shift+Click is highly erratic.
 			// Even though it is very slow, we need to manually recount.
-			pFileListCtrl->m_pFilelistStatusBar->UnselectAll();
+			m_pFilelistStatusBar->UnselectAll();
 			int item = -1;
-			while ((item = pFileListCtrl->GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1)
+			while ((item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1)
 			{
-				if (pFileListCtrl->m_hasParent && !item)
+				if (m_hasParent && !item)
 					continue;
 
-				const int index = pFileListCtrl->m_indexMapping[item];
-				const CFileData& data = pFileListCtrl->m_fileData[index];
+				const int index = m_indexMapping[item];
+				const CFileData& data = m_fileData[index];
 				if (data.flags == fill)
 					continue;
 
-				if (pFileListCtrl->ItemIsDir(index))
-					pFileListCtrl->m_pFilelistStatusBar->SelectDirectory();
+				if (ItemIsDir(index))
+					m_pFilelistStatusBar->SelectDirectory();
 				else
-					pFileListCtrl->m_pFilelistStatusBar->SelectFile(pFileListCtrl->ItemGetSize(index));
+					m_pFilelistStatusBar->SelectFile(ItemGetSize(index));
 			}
 		}
 		else
@@ -137,38 +132,38 @@ template<class CFileData> LRESULT CALLBACK CFileListCtrl<CFileData>::WindowProc(
 			wxASSERT(pNmOdStateChange->iFrom <= pNmOdStateChange->iTo);
 			for (int i = pNmOdStateChange->iFrom; i <= pNmOdStateChange->iTo; i++)
 			{
-				if (pFileListCtrl->m_hasParent && !i)
+				if (m_hasParent && !i)
 					continue;
 
-				const int index = pFileListCtrl->m_indexMapping[i];
-				const CFileData& data = pFileListCtrl->m_fileData[index];
+				const int index = m_indexMapping[i];
+				const CFileData& data = m_fileData[index];
 				if (data.flags == fill)
 					continue;
 
-				if (pFileListCtrl->ItemIsDir(index))
-					pFileListCtrl->m_pFilelistStatusBar->SelectDirectory();
+				if (ItemIsDir(index))
+					m_pFilelistStatusBar->SelectDirectory();
 				else
-					pFileListCtrl->m_pFilelistStatusBar->SelectFile(pFileListCtrl->ItemGetSize(index));
+					m_pFilelistStatusBar->SelectFile(ItemGetSize(index));
 			}
 		}
-		return 0;
+		return true;
 	}
 	else if (pNmhdr->code == LVN_ITEMCHANGED)
 	{
-		if (pFileListCtrl->m_insideSetSelection)
-			return 0;
+		if (m_insideSetSelection)
+			return true;
 
 		NMLISTVIEW* pNmListView = (NMLISTVIEW*)lParam;
 
 		// Item of -1 means change applied to all items
 		if (pNmListView->iItem == -1 && !(pNmListView->uNewState & LVIS_SELECTED))
 		{
-			pFileListCtrl->m_pFilelistStatusBar->UnselectAll();
+			m_pFilelistStatusBar->UnselectAll();
 		}
 	}
 	else if (pNmhdr->code == LVN_MARQUEEBEGIN)
 	{
-		pFileListCtrl->SetFocus();
+		SetFocus();
 	}
 	else if (pNmhdr->code == LVN_GETDISPINFO)
 	{
@@ -179,11 +174,11 @@ template<class CFileData> LRESULT CALLBACK CFileListCtrl<CFileData>::WindowProc(
 		LV_ITEM& lvi = info->item;
 		long item = lvi.iItem;
 
-		int column = pFileListCtrl->m_pVisibleColumnMapping[lvi.iSubItem];
+		int column = m_pVisibleColumnMapping[lvi.iSubItem];
 
 		if (lvi.mask & LVIF_TEXT)
 		{
-			wxString text = pFileListCtrl->GetItemText(item, column);
+			wxString text = GetItemText(item, column);
 			wxStrncpy(lvi.pszText, text, lvi.cchTextMax - 1);
 			lvi.pszText[lvi.cchTextMax - 1] = 0;
 		}
@@ -191,18 +186,18 @@ template<class CFileData> LRESULT CALLBACK CFileListCtrl<CFileData>::WindowProc(
 		if (lvi.mask & LVIF_IMAGE)
 		{
 			if (!lvi.iSubItem)
-				lvi.iImage = pFileListCtrl->OnGetItemImage(item);
+				lvi.iImage = OnGetItemImage(item);
 			else
 				lvi.iImage = -1;
 		}
 
 		if (!lvi.iSubItem)
-			lvi.state = INDEXTOOVERLAYMASK(pFileListCtrl->GetOverlayIndex(lvi.iItem));
+			lvi.state = INDEXTOOVERLAYMASK(GetOverlayIndex(lvi.iItem));
 
-		return 0;
+		return true;
 	}
 
-	return CallWindowProc(pFileListCtrl->m_prevWndproc, hWnd, uMsg, wParam, lParam);
+	return wxListCtrlEx::MSWOnNotify(idCtrl, lParam, result);
 }
 #endif
 
@@ -248,13 +243,9 @@ static gboolean gtk_button_release_event(GtkWidget*, void *gdk_event, CGtkEventC
 
 template<class CFileData> CFileListCtrl<CFileData>::CFileListCtrl(wxWindow* pParent, CState* pState, CQueueView* pQueue, bool border /*=false*/)
 : wxListCtrlEx(pParent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL | wxLC_VIRTUAL | wxLC_REPORT | wxLC_EDIT_LABELS | (border ? wxBORDER_SUNKEN : wxNO_BORDER)),
-	CComparableListing(this), CSystemImageList(16)
+	CComparableListing(this)
 {
-#ifdef __WXMSW__
-	m_pHeaderImageList = 0;
-#endif
-	m_header_icon_index.down = m_header_icon_index.up = -1;
-
+	CreateSystemImageList(16);
 	m_pQueue = pQueue;
 
 	m_sortColumn = 0;
@@ -272,10 +263,6 @@ template<class CFileData> CFileListCtrl<CFileData>::CFileListCtrl(wxWindow* pPar
 
 	m_insideSetSelection = false;
 #ifdef __WXMSW__
-	// Subclass window
-	m_hwnd_map[(HWND)pParent->GetHandle()] = (char*)this;
-	m_prevWndproc = (WNDPROC)SetWindowLongPtr((HWND)pParent->GetHandle(), GWLP_WNDPROC, (LONG_PTR)WindowProc);
-
 	// Enable use of overlay images
 	DWORD mask = ListView_GetCallbackMask((HWND)GetHandle()) | LVIS_OVERLAYMASK;
 	ListView_SetCallbackMask((HWND)GetHandle(), mask);
@@ -294,77 +281,6 @@ template<class CFileData> CFileListCtrl<CFileData>::CFileListCtrl(wxWindow* pPar
 
 template<class CFileData> CFileListCtrl<CFileData>::~CFileListCtrl()
 {
-#ifdef __WXMSW__
-	delete m_pHeaderImageList;
-
-	// Remove subclass
-	if (m_prevWndproc != 0)
-	{
-		SetWindowLongPtr((HWND)GetParent()->GetHandle(), GWLP_WNDPROC, (LONG_PTR)m_prevWndproc);
-		std::map<HWND, char*>::iterator iter = m_hwnd_map.find((HWND)GetParent()->GetHandle());
-		if (iter != m_hwnd_map.end())
-			m_hwnd_map.erase(iter);
-	}
-#endif
-}
-
-template<class CFileData> void CFileListCtrl<CFileData>::InitHeaderImageList()
-{
-#ifdef __WXMSW__
-	// Initialize imagelist for list header
-	m_pHeaderImageList = new wxImageListEx(8, 8, true, 3);
-
-	wxBitmap bmp;
-
-	bmp.LoadFile(wxGetApp().GetResourceDir() + _T("up.png"), wxBITMAP_TYPE_PNG);
-	m_pHeaderImageList->Add(bmp);
-	bmp.LoadFile(wxGetApp().GetResourceDir() + _T("down.png"), wxBITMAP_TYPE_PNG);
-	m_pHeaderImageList->Add(bmp);
-
-	HWND hWnd = (HWND)GetHandle();
-	if (!hWnd)
-	{
-		delete m_pHeaderImageList;
-		m_pHeaderImageList = 0;
-		return;
-	}
-
-	HWND header = (HWND)SendMessage(hWnd, LVM_GETHEADER, 0, 0);
-	if (!header)
-	{
-		delete m_pHeaderImageList;
-		m_pHeaderImageList = 0;
-		return;
-	}
-
-	TCHAR buffer[1000] = {0};
-	HDITEM item;
-	item.mask = HDI_TEXT;
-	item.pszText = buffer;
-	item.cchTextMax = 999;
-	SendMessage(header, HDM_GETITEM, 0, (LPARAM)&item);
-
-	SendMessage(header, HDM_SETIMAGELIST, 0, (LPARAM)m_pHeaderImageList->GetHandle());
-
-	m_header_icon_index.up = 0;
-	m_header_icon_index.down = 1;
-#else
-
-	wxColour colour = wxSystemSettings::GetColour(wxSYS_COLOUR_3DFACE);
-
-	wxString lightness;
-	if (colour.Red() + colour.Green() + colour.Blue() > 3 * 128)
-		lightness = _T("DARK");
-	else
-		lightness = _T("LIGHT");
-
-	wxBitmap bmp;
-
-	bmp = wxArtProvider::GetBitmap(_T("ART_SORT_UP_") + lightness,  wxART_OTHER, wxSize(16, 16));
-	m_header_icon_index.up = m_pImageList->Add(bmp);
-	bmp = wxArtProvider::GetBitmap(_T("ART_SORT_DOWN_") + lightness,  wxART_OTHER, wxSize(16, 16));
-	m_header_icon_index.down = m_pImageList->Add(bmp);
-#endif
 }
 
 template<class CFileData> void CFileListCtrl<CFileData>::SortList(int column /*=-1*/, int direction /*=-1*/, bool updateSelections /*=true*/)
@@ -377,7 +293,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::SortList(int column /*=
 		{
 			const int oldVisibleColumn = GetColumnVisibleIndex(m_sortColumn);
 			if (oldVisibleColumn != -1)
-				SetHeaderIconIndex(oldVisibleColumn, -1);
+				SetHeaderSortIconIndex(oldVisibleColumn, -1);
 		}
 	}
 	else
@@ -393,7 +309,7 @@ template<class CFileData> void CFileListCtrl<CFileData>::SortList(int column /*=
 		column = 0;
 	}
 
-	SetHeaderIconIndex(newVisibleColumn, direction ? m_header_icon_index.down : m_header_icon_index.up);
+	SetHeaderSortIconIndex(newVisibleColumn, direction);
 
 	// Remember which files are selected
 	bool *selected = 0;
