@@ -24,12 +24,12 @@ EVT_CHOICE(XRCID("ID_LOGONTYPE"), CManualTransfer::OnLogontypeSelChanged)
 END_EVENT_TABLE()
 
 CManualTransfer::CManualTransfer(CQueueView* pQueueView)
+	: m_local_file_exists()
+	, m_pServer()
+	, m_pLastSite()
+	, m_pState()
+	, m_pQueueView(pQueueView)
 {
-	m_pQueueView = pQueueView;
-
-	m_local_file_exists = false;
-	m_pServer = 0;
-	m_pLastSite = 0;
 }
 
 CManualTransfer::~CManualTransfer()
@@ -50,10 +50,11 @@ void CManualTransfer::Show(wxWindow* pParent, CState* pState)
 	pProtocol->Append(CServer::GetProtocolName(SFTP));
 	pProtocol->Append(CServer::GetProtocolName(FTPS));
 	pProtocol->Append(CServer::GetProtocolName(FTPES));
+	//pProtocol->Append(CServer::GetProtocolName(INSECURE_FTP));
 
 	wxChoice* pChoice = XRCCTRL(*this, "ID_LOGONTYPE", wxChoice);
 	wxASSERT(pChoice);
-	for (int i = 0; i < LOGONTYPE_MAX; i++)
+	for (int i = 0; i < LOGONTYPE_MAX; ++i)
 		pChoice->Append(CServer::GetNameFromLogonType((enum LogonType)i));
 
 	if (m_pState->GetServer())
@@ -89,6 +90,9 @@ void CManualTransfer::Show(wxWindow* pParent, CState* pState)
 		break;
 	}
 
+	wxSize minSize = GetSizer()->GetMinSize();
+	SetClientSize(minSize);
+
 	ShowModal();
 }
 
@@ -366,7 +370,10 @@ void CManualTransfer::OnOK(wxCommandEvent& event)
 		return;
 	}
 
-	m_pQueueView->QueueFile(!start, download, localPath, name, remote_file, path, *m_pServer, -1);
+	m_pQueueView->QueueFile(!start, download,
+		download ? remote_file : name,
+		(remote_file != name) ? (download ? name : remote_file) : wxString(),
+		localPath, path, *m_pServer, -1);
 
 	// Restore old data type
 	COptions::Get()->SetOption(OPTION_ASCIIBINARY, old_data_type);
@@ -488,7 +495,7 @@ bool CManualTransfer::VerifyServer()
 	if (user != _T(""))
 	{
 		bool space_only = true;
-		for (unsigned int i = 0; i < user.Len(); i++)
+		for (unsigned int i = 0; i < user.Len(); ++i)
 		{
 			if (user[i] != ' ')
 			{
