@@ -55,14 +55,21 @@ public:
 
 	virtual enum QueueItemType GetType() const = 0;
 
+	wxDateTime GetTime() const { return m_time; }
+	void UpdateTime() { m_time = wxDateTime::Now(); }
+
+	const wxString& GetIndent() const;
+
+	const std::vector<CQueueItem*>& GetChildren() const { return m_children; }
+	int GetRemovedAtFront() const { return m_removed_at_front; }
+
 protected:
 	CQueueItem();
-	wxString GetIndent();
 
 	CQueueItem* m_parent;
 
 	int m_visibleOffspring; // Visible offspring over all sublevels
-	wxString m_indent;
+	int m_indent;
 
 	int m_maxCachedIndex;
 
@@ -75,6 +82,8 @@ protected:
 
 	friend class CServerItem;
 
+	wxDateTime m_time;
+
 private:
 	std::vector<CQueueItem*> m_children;
 
@@ -135,27 +144,47 @@ struct t_EngineData;
 class CFileItem : public CQueueItem
 {
 public:
-	CFileItem(CServerItem* parent, bool queued, bool download, const wxString& localFile,
-			const wxString& remoteFile, const CServerPath& remotePath, wxLongLong size);
+	CFileItem(CServerItem* parent, bool queued, bool download,
+		const wxString& sourceFile, const wxString& targetFile,
+		const CLocalPath& localPath, const CServerPath& remotePath, wxLongLong size);
+
 	virtual ~CFileItem();
 
 	virtual void SetPriority(enum QueuePriority priority);
 	void SetPriorityRaw(enum QueuePriority priority);
 	enum QueuePriority GetPriority() const;
 
-	wxString GetLocalFile() const { return m_localFile; }
-	wxString GetRemoteFile() const { return m_remoteFile; }
-	CServerPath GetRemotePath() const { return m_remotePath; }
-	wxLongLong GetSize() const { return m_size; }
+	const wxString& GetLocalFile() const { return !Download() ? GetSourceFile() : (m_targetFile.empty() ? m_sourceFile : m_targetFile); }
+	const wxString& GetRemoteFile() const { return Download() ? GetSourceFile() : (m_targetFile.empty() ? m_sourceFile : m_targetFile); }
+	const wxString& GetSourceFile() const { return m_sourceFile; }
+	const wxString& GetTargetFile() const { return m_targetFile; }
+	const CLocalPath& GetLocalPath() const { return m_localPath; }
+	const CServerPath& GetRemotePath() const { return m_remotePath; }
+	const wxLongLong& GetSize() const { return m_size; }
 	void SetSize(wxLongLong size) { m_size = size; }
-	bool Download() const { return m_download; }
-	bool Queued() const { return m_queued; }
+	inline bool Download() const { return flags & flag_download; }
+	
+	inline bool queued() const { return (flags & flag_queued) != 0; }
+	inline void set_queued(bool q)
+	{
+		if (q)
+			flags |= flag_queued;
+		else
+			flags &= ~flag_queued;
+	}
 
-	wxString GetIndent() { return m_indent; }
+	inline bool pending_remove() const { return (flags & flag_remove) != 0; }
+	inline void set_pending_remove(bool remove)
+	{
+		if (remove)
+			flags |= flag_remove;
+		else
+			flags &= ~flag_remove;
+	}
 
 	virtual enum QueueItemType GetType() const { return QueueItemType_File; }
 
-	bool IsActive() const { return m_active; }
+	bool IsActive() const { return (flags & flag_active) != 0; }
 	virtual void SetActive(bool active);
 	
 	virtual void SaveItem(TiXmlElement* pElement) const;
@@ -163,12 +192,9 @@ public:
 	virtual bool TryRemoveAll(); // Removes a inactive childrens, queues active children for removal.
 								 // Returns true if item can be removed itself
 
-	void SetLocalFile(const wxString &file);
-	void SetRemoteFile(const wxString &file);
+	void SetTargetFile(const wxString &file);
 
-	bool m_queued;
 	int m_errorCount;
-	bool m_remove;
 	CEditHandler::fileType m_edit;
 
 	wxString m_statusMessage;
@@ -179,25 +205,41 @@ public:
 
 	enum CFileExistsNotification::OverwriteAction m_defaultFileExistsAction;
 
-	bool m_madeProgress;
+	inline bool made_progress() const { return (flags & flag_made_progress) != 0; }
+	inline void set_made_progress(bool made_progress)
+	{
+		if (made_progress)
+			flags |= flag_made_progress;
+		else
+			flags &= ~flag_made_progress;
+	}
 
 	enum CFileExistsNotification::OverwriteAction m_onetime_action;
 
 protected:
+	enum
+	{
+		flag_download = 0x01,
+		flag_active = 0x02,
+		flag_made_progress = 0x04,
+		flag_queued = 0x08,
+		flag_remove = 0x10
+	};
+	int flags;
+
 	enum QueuePriority m_priority;
 
-	bool m_download;
-	wxString m_localFile;
-	wxString m_remoteFile;
-	CServerPath m_remotePath;
+	wxString m_sourceFile;
+	wxString m_targetFile;
+	const CLocalPath m_localPath;
+	const CServerPath m_remotePath;
 	wxLongLong m_size;
-	bool m_active;
 };
 
 class CFolderItem : public CFileItem
 {
 public:
-	CFolderItem(CServerItem* parent, bool queued, const wxString& localFile);
+	CFolderItem(CServerItem* parent, bool queued, const CLocalPath& localPath);
 	CFolderItem(CServerItem* parent, bool queued, const CServerPath& remotePath, const wxString& remoteFile);
 	
 	virtual enum QueueItemType GetType() const { return QueueItemType_Folder; }
@@ -210,20 +252,21 @@ public:
 class CFolderScanItem : public CQueueItem
 {
 public:
-	CFolderScanItem(CServerItem* parent, bool queued, bool download, const wxString& localPath, const CServerPath& remotePath);
+	CFolderScanItem(CServerItem* parent, bool queued, bool download, const CLocalPath& localPath, const CServerPath& remotePath);
 	virtual ~CFolderScanItem() { }
 
 	virtual enum QueueItemType GetType() const { return QueueItemType_FolderScan; }
-	wxString GetLocalPath() const { return m_localPath; }
+	CLocalPath GetLocalPath() const { return m_localPath; }
 	CServerPath GetRemotePath() const { return m_remotePath; }
 	bool Download() const { return m_download; }
-	bool Queued() const { return m_queued; }
 	int GetCount() const { return m_count; }
 	virtual bool TryRemoveAll();
 
+	bool queued() const { return m_queued; }
+	void set_queued(bool q) { m_queued = q; }
+
 	wxString m_statusMessage;
 
-	bool m_queued;
 	volatile bool m_remove;
 	bool m_active;
 
@@ -232,11 +275,12 @@ public:
 	enum CFileExistsNotification::OverwriteAction m_defaultFileExistsAction;
 
 	bool m_dir_is_empty;
-	wxString m_current_local_path;
+	CLocalPath m_current_local_path;
 	CServerPath m_current_remote_path;
 
 protected:
-	wxString m_localPath;
+	bool m_queued;
+	CLocalPath m_localPath;
 	CServerPath m_remotePath;
 	bool m_download;
 };
@@ -254,11 +298,22 @@ class CQueue;
 class CQueueViewBase : public wxListCtrlEx
 {
 public:
+
+	enum ColumnId
+	{
+		colLocalName,
+		colDirection,
+		colRemoteName,
+		colSize,
+		colPriority,
+		colTime,
+		colTransferStatus,
+		colErrorReason
+	};
+
 	CQueueViewBase(CQueue* parent, int index, const wxString& title);
 	virtual ~CQueueViewBase();
 
-	void CreateColumns(const wxString& lastColumnName = _T(""));
-
 	// Gets item for given server or creates new if it doesn't exist
 	CServerItem* CreateServerItem(const CServer& server);
 
@@ -275,6 +330,9 @@ public:
 
 protected:
 
+	void CreateColumns(std::list<ColumnId> const& extraColumns = std::list<ColumnId>());
+	void AddQueueColumn(ColumnId id);
+
 	// Gets item for given server
 	CServerItem* GetServerItem(const CServer& server);
 
@@ -285,6 +343,7 @@ protected:
 	int GetItemIndex(const CQueueItem* item);
 
 	virtual wxString OnGetItemText(long item, long column) const;
+	virtual wxString OnGetItemText(CQueueItem* pItem, ColumnId column) const;
 	virtual int OnGetItemImage(long item) const;
 
 	void RefreshItem(const CQueueItem* pItem);
@@ -319,6 +378,8 @@ protected:
 
 	wxTimer m_filecount_delay_timer;
 
+	std::vector<ColumnId> m_columns;
+
 	DECLARE_EVENT_TABLE();
 	void OnEraseBackground(wxEraseEvent& event);
 	void OnNavigationKey(wxNavigationKeyEvent& event);
