@@ -223,8 +223,6 @@ void CQueueStorage::Impl::ReadLocalPaths()
 	if (!selectLocalPathQuery_)
 		return;
 
-	sqlite3_reset(selectLocalPathQuery_);
-
 	int res;
 	do
 	{
@@ -239,6 +237,8 @@ void CQueueStorage::Impl::ReadLocalPaths()
 		}
 	}
 	while (res == SQLITE_BUSY || res == SQLITE_ROW);
+
+	sqlite3_reset(selectLocalPathQuery_);
 }
 
 
@@ -247,8 +247,6 @@ void CQueueStorage::Impl::ReadRemotePaths()
 	if (!selectRemotePathQuery_)
 		return;
 
-	sqlite3_reset(selectRemotePathQuery_);
-
 	int res;
 	do
 	{
@@ -263,6 +261,8 @@ void CQueueStorage::Impl::ReadRemotePaths()
 		}
 	}
 	while (res == SQLITE_BUSY || res == SQLITE_ROW);
+
+	sqlite3_reset(selectRemotePathQuery_);
 }
 
 
@@ -328,7 +328,6 @@ wxLongLong_t CQueueStorage::Impl::SaveLocalPath(const CLocalPath& path)
 	if (it != localPaths_.end())
 		return it->second;
 
-	sqlite3_reset(insertLocalPathQuery_);
 	Bind(insertLocalPathQuery_, path_table_column_names::path, path.GetPath());
 
 	int res;
@@ -336,6 +335,8 @@ wxLongLong_t CQueueStorage::Impl::SaveLocalPath(const CLocalPath& path)
 		res = sqlite3_step(insertLocalPathQuery_);
 	} while (res == SQLITE_BUSY);
 	
+	sqlite3_reset(insertLocalPathQuery_);
+
 	if (res == SQLITE_DONE)
 	{
 		wxLongLong_t id = sqlite3_last_insert_rowid(db_);
@@ -354,7 +355,6 @@ wxLongLong_t CQueueStorage::Impl::SaveRemotePath(const CServerPath& path)
 	if (it != remotePaths_.end())
 		return it->second;
 
-	sqlite3_reset(insertRemotePathQuery_);
 	Bind(insertRemotePathQuery_, path_table_column_names::path, path.GetSafePath());
 
 	int res;
@@ -362,6 +362,8 @@ wxLongLong_t CQueueStorage::Impl::SaveRemotePath(const CServerPath& path)
 		res = sqlite3_step(insertRemotePathQuery_);
 	} while (res == SQLITE_BUSY);
 	
+	sqlite3_reset(insertRemotePathQuery_);
+
 	if (res == SQLITE_DONE)
 	{
 		wxLongLong_t id = sqlite3_last_insert_rowid(db_);
@@ -534,7 +536,8 @@ bool CQueueStorage::Impl::Bind(sqlite3_stmt* statement, int index, int value)
 
 bool CQueueStorage::Impl::Bind(sqlite3_stmt* statement, int index, wxLongLong_t value)
 {
-	return sqlite3_bind_int64(statement, index, value) == SQLITE_OK;
+	int res = sqlite3_bind_int64(statement, index, value);
+	return res == SQLITE_OK;
 }
 
 
@@ -585,7 +588,6 @@ bool CQueueStorage::Impl::SaveServer(const CServerItem& item)
 	bool kiosk_mode = COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 0;
 	
 	const CServer& server = item.GetServer();
-	sqlite3_reset(insertServerQuery_);
 	
 	Bind(insertServerQuery_, server_table_column_names::host, server.GetHost());
 	Bind(insertServerQuery_, server_table_column_names::port, static_cast<int>(server.GetPort()));
@@ -691,6 +693,8 @@ bool CQueueStorage::Impl::SaveServer(const CServerItem& item)
 		res = sqlite3_step(insertServerQuery_);
 	} while (res == SQLITE_BUSY);
 	
+	sqlite3_reset(insertServerQuery_);
+
 	bool ret = res == SQLITE_DONE;
 	if (ret)
 	{
@@ -716,8 +720,6 @@ bool CQueueStorage::Impl::SaveFile(wxLongLong server, const CFileItem& file)
 	if (file.m_edit != CEditHandler::none)
 		return true;
 
-	sqlite3_reset(insertFileQuery_);
-
 	Bind(insertFileQuery_, file_table_column_names::source_file, file.GetSourceFile());
 	if (file.GetTargetFile().empty())
 		BindNull(insertFileQuery_, file_table_column_names::target_file);
@@ -754,14 +756,14 @@ bool CQueueStorage::Impl::SaveFile(wxLongLong server, const CFileItem& file)
 		res = sqlite3_step(insertFileQuery_);
 	} while (res == SQLITE_BUSY);
 
+	sqlite3_reset(insertFileQuery_);
+
 	return res == SQLITE_DONE;
 }
 
 
 bool CQueueStorage::Impl::SaveDirectory(wxLongLong server, const CFolderItem& directory)
 {
-	sqlite3_reset(insertFileQuery_);
-
 	if (download)
 		BindNull(insertFileQuery_, file_table_column_names::source_file);
 	else
@@ -792,6 +794,8 @@ bool CQueueStorage::Impl::SaveDirectory(wxLongLong server, const CFolderItem& di
 		res = sqlite3_step(insertFileQuery_);
 	} while (res == SQLITE_BUSY);
 
+	sqlite3_reset(insertFileQuery_);
+
 	return res == SQLITE_DONE;
 }
 
@@ -991,7 +995,7 @@ wxLongLong_t CQueueStorage::Impl::ParseFileFromRow(CFileItem** pItem)
 		if (sourceFile.empty() || localPath.empty() ||
 			remotePath.IsEmpty() ||
 			size < -1 ||
-			priority <= 0 || priority >= PRIORITY_COUNT ||
+			priority < 0 || priority >= PRIORITY_COUNT ||
 			errorCount < 0)
 		{
 			return INVALID_DATA;
@@ -1091,6 +1095,13 @@ wxLongLong_t CQueueStorage::GetServer(CServer& server, bool fromBeginning)
 			else if (res == SQLITE_DONE)
 			{
 				ret = 0;
+				sqlite3_reset(d_->selectServersQuery_);
+				break;
+			}
+			else
+			{
+				ret = -1;
+				sqlite3_reset(d_->selectServersQuery_);
 				break;
 			}
 		}
@@ -1134,6 +1145,13 @@ wxLongLong_t CQueueStorage::GetFile(CFileItem** pItem, wxLongLong_t server)
 			else if (res == SQLITE_DONE)
 			{
 				ret = 0;
+				sqlite3_reset(d_->selectFilesQuery_);
+				break;
+			}
+			else
+			{
+				ret = -1;
+				sqlite3_reset(d_->selectFilesQuery_);
 				break;
 			}
 		}
