@@ -15,7 +15,10 @@ END_EVENT_TABLE()
 CQueueViewFailed::CQueueViewFailed(CQueue* parent, int index)
 	: CQueueViewBase(parent, index, _("Failed transfers"))
 {
-	CreateColumns(_("Reason"));
+	std::list<ColumnId> extraCols;
+	extraCols.push_back(colTime);
+	extraCols.push_back(colErrorReason);
+	CreateColumns(extraCols);
 }
 
 CQueueViewFailed::CQueueViewFailed(CQueue* parent, int index, const wxString& title)
@@ -157,7 +160,7 @@ bool CQueueViewFailed::RequeueFileItem(CFileItem* pFileItem, CServerItem* pServe
 	CQueueView* pQueueView = m_pQueue->GetQueueView();
 
 	pFileItem->m_errorCount = 0;
-	pFileItem->m_statusMessage.Clear();
+	pFileItem->m_statusMessage.clear();
 
 	if (!pFileItem->Download() && !wxFileName::FileExists(pFileItem->GetLocalPath().GetPath() + pFileItem->GetLocalFile()))
 	{
@@ -183,7 +186,7 @@ bool CQueueViewFailed::RequeueFileItem(CFileItem* pFileItem, CServerItem* pServe
 				delete pFileItem;
 				return false;
 			}
-			pFileItem->SetLocalFile(file);
+			pFileItem->SetTargetFile(file);
 		}
 		else if (state == CEditHandler::upload_and_remove_failed)
 		{
