@@ -3,6 +3,7 @@
 #include "commandqueue.h"
 #include "chmoddialog.h"
 #include "filter.h"
+#include "Options.h"
 #include "queue.h"
 #include "local_filesys.h"
 
@@ -156,6 +157,9 @@ bool CRecursiveOperation::BelowRecursionRoot(const CServerPath& path, CNewDir &d
 	return false;
 }
 
+// Defined in RemoteListView.cpp
+extern wxString StripVMSRevision(const wxString& name);
+
 void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDirectoryListing)
 {
 	if (!pDirectoryListing)
@@ -225,7 +229,7 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 		}
 		else if (m_operationMode == recursive_addtoqueue)
 		{
-			m_pQueue->QueueFile(true, true, dir.localDir, _T(""), _T(""), CServerPath(), *pServer, -1);
+			m_pQueue->QueueFile(true, true, _T(""), _T(""), dir.localDir, CServerPath(), *pServer, -1);
 			m_pQueue->QueueFile_Finish(false);
 		}
 	}
@@ -241,7 +245,7 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 	
 	bool added = false;
 
-	for (int i = pDirectoryListing->GetCount() - 1; i >= 0; i--)
+	for (int i = pDirectoryListing->GetCount() - 1; i >= 0; --i)
 	{
 		const CDirentry& entry = (*pDirectoryListing)[i];
 
@@ -280,18 +284,24 @@ void CRecursiveOperation::ProcessDirectoryListing(const CDirectoryListing* pDire
 			case recursive_download:
 			case recursive_download_flatten:
 				{
+					wxString localFile = CQueueView::ReplaceInvalidCharacters(entry.name);
+					if (pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+						localFile = StripVMSRevision(localFile);
 					m_pQueue->QueueFile(m_operationMode == recursive_addtoqueue, true,
-						dir.localDir, CQueueView::ReplaceInvalidCharacters(entry.name),
-						entry.name, pDirectoryListing->path, *pServer, entry.size);
+						entry.name, (entry.name == localFile) ? wxString() : localFile,
+						dir.localDir, pDirectoryListing->path, *pServer, entry.size);
 					added = true;
 				}
 				break;
 			case recursive_addtoqueue:
 			case recursive_addtoqueue_flatten:
 				{
+					wxString localFile = CQueueView::ReplaceInvalidCharacters(entry.name);
+					if (pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+						localFile = StripVMSRevision(localFile);
 					m_pQueue->QueueFile(true, true,
-						dir.localDir, CQueueView::ReplaceInvalidCharacters(entry.name),
-						entry.name, pDirectoryListing->path, *pServer, entry.size);
+						entry.name, (entry.name == localFile) ? wxString() : localFile,
+						dir.localDir, pDirectoryListing->path, *pServer, entry.size);
 					added = true;
 				}
 				break;
@@ -426,7 +436,7 @@ void CRecursiveOperation::LinkIsNotDir()
 		wxString localFile = dir.subdir;
 		if (m_operationMode != recursive_addtoqueue_flatten && m_operationMode != recursive_download_flatten)
 			localPath.MakeParent();
-		m_pQueue->QueueFile(m_operationMode == recursive_addtoqueue || m_operationMode == recursive_addtoqueue_flatten, true, localPath, localFile, dir.subdir, dir.parent, *pServer, -1);
+		m_pQueue->QueueFile(m_operationMode == recursive_addtoqueue || m_operationMode == recursive_addtoqueue_flatten, true, dir.subdir, (dir.subdir == localFile) ? wxString() : localFile, localPath, dir.parent, *pServer, -1);
 		m_pQueue->QueueFile_Finish(m_operationMode != recursive_addtoqueue);
 	}
 
