@@ -3,6 +3,7 @@
 #include <wx/tokenzr.h>
 #include "dialogex.h"
 #include "ipcmutex.h"
+#include "Options.h"
 
 CVerifyCertDialog::~CVerifyCertDialog()
 {
@@ -75,6 +76,9 @@ void CVerifyCertDialog::ShowVerificationDialog(CCertificateNotification* pNotifi
 		m_pDlg->Load(0, _T("ID_VERIFYCERT"));
 
 		m_pDlg->WrapText(m_pDlg, XRCID("ID_DESC"), 400);
+
+		if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) == 2)
+			XRCCTRL(*m_pDlg, "ID_ALWAYS", wxCheckBox)->Hide();
 	}
 
 	m_certificates = pNotification->GetCertificates();
@@ -143,6 +147,8 @@ void CVerifyCertDialog::ShowVerificationDialog(CCertificateNotification* pNotifi
 			else
 			{
 				t_certData cert;
+				cert.host = pNotification->GetHost();
+				cert.port = pNotification->GetPort();
 				const unsigned char* data = m_certificates[0].GetRawData(cert.len);
 				cert.data = new unsigned char[cert.len];
 				memcpy(cert.data, data, cert.len);
@@ -176,8 +182,10 @@ void CVerifyCertDialog::ParseDN(wxDialog* pDlg, const wxString& dn, wxSizer* pSi
 	ParseDN_by_prefix(pDlg, tokenlist, _T("ST"), _("State or province:"), pSizer);
 	ParseDN_by_prefix(pDlg, tokenlist, _T("L"), _("Locality:"), pSizer);
 	ParseDN_by_prefix(pDlg, tokenlist, _T("2.5.4.17"), _("Postal code:"), pSizer, true);
+	ParseDN_by_prefix(pDlg, tokenlist, _T("postalCode"), _("Postal code:"), pSizer, true);
 	ParseDN_by_prefix(pDlg, tokenlist, _T("STREET"), _("Street:"), pSizer);
 	ParseDN_by_prefix(pDlg, tokenlist, _T("EMAIL"), _("E-Mail:"), pSizer);
+	ParseDN_by_prefix(pDlg, tokenlist, _T("serialNumber"), _("Serial number:"), pSizer);
 	ParseDN_by_prefix(pDlg, tokenlist, _T("1.3.6.1.4.1.311.60.2.1.3"), _("Jurisdiction country:"), pSizer, true);
 	ParseDN_by_prefix(pDlg, tokenlist, _T("1.3.6.1.4.1.311.60.2.1.2"), _("Jurisdiction state or province:"), pSizer, true);	
 	ParseDN_by_prefix(pDlg, tokenlist, _T("1.3.6.1.4.1.311.60.2.1.1"), _("Jurisdiction locality:"), pSizer, true);
@@ -254,13 +262,19 @@ bool CVerifyCertDialog::IsTrusted(CCertificateNotification* pNotification)
 	CCertificate cert =  pNotification->GetCertificates()[0];
 	const unsigned char* data = cert.GetRawData(len);
 
-	return IsTrusted(data, len, false);
+	return IsTrusted(pNotification->GetHost(), pNotification->GetPort(), data, len, false);
 }
 
-bool CVerifyCertDialog::IsTrusted(const unsigned char* data, unsigned int len, bool permanentOnly)
+bool CVerifyCertDialog::IsTrusted(const wxString& host, int port, const unsigned char* data, unsigned int len, bool permanentOnly)
 {
 	for (std::list<t_certData>::const_iterator iter = m_trustedCerts.begin(); iter != m_trustedCerts.end(); iter++)
 	{
+		if (host != iter->host)
+			continue;
+
+		if (port != iter->port)
+			continue;
+
 		if (iter->len != len)
 			continue;
 
@@ -273,6 +287,12 @@ bool CVerifyCertDialog::IsTrusted(const unsigned char* data, unsigned int len, b
 
 	for (std::list<t_certData>::const_iterator iter = m_sessionTrustedCerts.begin(); iter != m_sessionTrustedCerts.end(); iter++)
 	{
+		if (host != iter->host)
+			continue;
+
+		if (port != iter->port)
+			continue;
+
 		if (iter->len != len)
 			continue;
 
@@ -378,6 +398,11 @@ void CVerifyCertDialog::LoadTrustedCerts(bool close /*=true*/)
 		if (value == _T("") || !(data.data = ConvertStringToHex(value, data.len)))
 			pRemove = pCert;
 
+		data.host = GetTextElement(pCert, "Host");
+		data.port = GetTextElementInt(pCert, "Port");
+		if (data.host.empty() || data.port < 1 || data.port > 65535)
+			pRemove = pCert;
+
 		wxLongLong activationTime = GetTextElementLongLong(pCert, "ActivationTime", 0);
 		if (activationTime == 0 || activationTime > wxDateTime::GetTimeNow())
 			pRemove = pCert;
@@ -386,7 +411,7 @@ void CVerifyCertDialog::LoadTrustedCerts(bool close /*=true*/)
 		if (expirationTime == 0 || expirationTime < wxDateTime::GetTimeNow())
 			pRemove = pCert;
 
-		if (IsTrusted(data.data, data.len, true))
+		if (IsTrusted(data.host, data.port, data.data, data.len, true)) // Weed out duplicates
 			pRemove = pCert;
 
 		if (!pRemove)
@@ -419,18 +444,23 @@ void CVerifyCertDialog::SetPermanentlyTrusted(const CCertificateNotification* co
 	CReentrantInterProcessMutexLocker mutex(MUTEX_TRUSTEDCERTS);
 	LoadTrustedCerts(false);
 
-	if (IsTrusted(data, len, true))
+	if (IsTrusted(pNotification->GetHost(), pNotification->GetPort(), data, len, true))
 	{
 		m_xmlFile.Close();
 		return;
 	}
 
 	t_certData cert;
+	cert.host = pNotification->GetHost();
+	cert.port = pNotification->GetPort();
 	cert.len = len;
 	cert.data = new unsigned char[len];
 	memcpy(cert.data, data, len);
 	m_trustedCerts.push_back(cert);
 
+	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) == 2)
+		return;
+
 	TiXmlElement* pElement = m_xmlFile.GetElement();
 	if (!pElement)
 	{
@@ -458,6 +488,9 @@ void CVerifyCertDialog::SetPermanentlyTrusted(const CCertificateNotification* co
 	time = certificate.GetExpirationTime().GetTicks();
 	AddTextElement(pCert, "ExpirationTime", time.ToString());
 
+	AddTextElement(pCert, "Host", pNotification->GetHost());
+	AddTextElement(pCert, "Port", pNotification->GetPort());
+
 	m_xmlFile.Save();
 	m_xmlFile.Close();
 }
