@@ -20,6 +20,8 @@
 #include "sftp.h"
 #include "int64.h"
 
+const char *const appname = "PSFTP";
+
 /*
  * Since SFTP is a request-response oriented protocol, it requires
  * no buffer management: when we send data, we stop and wait for an
@@ -2904,7 +2906,8 @@ int from_backend(void *frontend, int is_stderr, const char *data, int datalen)
      */
     if (is_stderr) {
 	if (len > 0)
-	    fwrite(data, 1, len, stderr);
+	    if (fwrite(data, 1, len, stderr) < len)
+		/* oh well */;
 	return 0;
     }
 
@@ -3326,7 +3329,6 @@ int psftp_main(int argc, char *argv[])
     int mode = 0;
     int modeflags = 0;
     char *batchfile = NULL;
-    int errors = 0;
 
     // FZ: Set proxy to none
     cfg.proxy_type = PROXY_NONE;
@@ -3353,7 +3355,6 @@ int psftp_main(int argc, char *argv[])
     do_defaults(NULL, &cfg);
     loaded_session = FALSE;
 
-    errors = 0;
     for (i = 1; i < argc; i++) {
 	int ret;
 	if (argv[i][0] != '-') {
